@@ -3,7 +3,7 @@ import sentry_sdk
 import logging
 from aws_xray_sdk.core import xray_recorder
 from aws_xray_sdk.core import patch_all
-from framework_python import AWSClient
+from .aws_client import AWSClient
 
 
 # Initialize sentry, logger and AWS X-Ray
